# Python 3
# Example python script for calculating ASHRAE 14 metrics
# Arguments:
#   sys.argv[1]  -  the full paths of the location of the project itself
#   sys.argv[2]  -  the full path of the output folder of the simulation case
#   sys.argv[3]  -  the expected output table name, as defined by tableName. In the script, .csv should be appended to the table name before written to the file
#   sys.argv[4]  -  Other arguments as specified in the scripts object in the RVX

import pandas as pd
import numpy as np
import csv
import sys
import re

# function which calculates the cv(rmse)
def cvrmse_function(observed, predicted, N):
    error = observed - predicted
    sqerror = error ** 2
    sumsqerror = np.sum(sqerror)
    meansqerror = sumsqerror / N
    rmse = np.sqrt(meansqerror)
    cvrmse = 100 * rmse / np.mean(observed);
    return cvrmse

# function which calculates the normalized mean bias error
def nmbe_function(observed, predicted, N):
    error = predicted - observed
    sbe = np.sum(error)
    mbe = sbe / N
    nmbe = 100 * mbe / np.mean(observed)
    return nmbe

# This script takes
args = sys.argv[4].split(';')

refdata = pd.read_csv(sys.argv[1] + args[1]) #read data from the reference file (path passed from the script)

in_file = sys.argv[2] + args[0] + ".csv"
indata = pd.read_csv(in_file)

rowcolno = indata.shape

#take heading row from the reference file
heading = list(refdata.loc[:1])
newheading = heading[0:1]
for h in heading [1:]:
    newheading += ['CVRMSE:' + re.sub('\\s*\[.*\].*', '[%]', h)]
    newheading += ['NMBE:' + re.sub('\\s*\[.*\].*', '[%]', h)]



outname = sys.argv[3] # output file name from the parameter passed to the script

rmsedata = ["NA"]

for column in range(1, rowcolno[1]):
    observed = np.array(refdata.iloc[:, column])
    predicted = np.array(indata.iloc[:, column])
    rmsedata.append(cvrmse_function(observed, predicted, rowcolno[0]))
    rmsedata.append(nmbe_function(observed, predicted, rowcolno[0]))

with open(outname, "w", newline='') as outfile:
    output=csv.writer(outfile)
    output.writerow(newheading)
    output.writerow(rmsedata)
