# Python 3
# Example python script for calculating ASHRAE 14 metrics
# Arguments:
#   sys.argv[1]  -  the full paths of the location of the project itself
#   sys.argv[2]  -  the full path of the output folder of the simulation case
#   sys.argv[3]  -  the expected output table name, as defined by tableName. In the script, .csv should be appended to the table name before written to the file
#   sys.argv[4]  -  Other arguments as specified in the scripts object in the RVX

import pandas as pd
import numpy as np
import csv
import sys

# function which calculates the root mean square error
def rmse_function(observed, predicted, N):
	error = observed - predicted
	sqerror = error ** 2
	sumsqerror = np.sum(sqerror)
	meansqerror = sumsqerror / N
	rmse = np.sqrt(meansqerror)
	return rmse
	
# This script takes 
args = sys.argv[4].split(';')

refdata = pd.read_csv(sys.argv[1] + args[1]) #read data from the reference file (path passed from the script)	

in_file = sys.argv[2] + args[0] + ".csv"
indata = pd.read_csv(in_file)


rowcolno = indata.shape

heading = list(refdata.loc[:1]) #take heading row from the reference file
	
outname = sys.argv[3] # output file name from the parameter passed to the script

rmsedata = ["AAA"]	
	
for column in range(1, rowcolno[1]):
	observed = np.array(refdata.iloc[:, column])
	predicted = np.array(indata.iloc[:, column])
	
	rmse = rmse_function(observed, predicted, rowcolno[0])
	rmsedata.append(rmse)
rmsedata = rmsedata

with open(outname, "w", newline='') as outfile:
	output=csv.writer(outfile)
	output.writerow(heading)
	output.writerow(rmsedata)
